@@ -1,13 +1,12 @@
 import sys
 import os
 import pathlib
-
+from PaperCrawlerUtil.common_util import basic_config
 sys.path.append(str(pathlib.Path(__file__).parent))
-__all__ = ["common_util", "crawler_util", "document_util", "office_util", "pdf_util"]
+__all__ = ["common_util", "crawler_util", "document_util", "office_util", "pdf_util", "research_util"]
 __author__ = "liwudi@liwudi.fun"
-__version__ = "0.1.7"
+__version__ = "0.1.14"
 __github__ = "https://github.com/Liwu-di/PaperCrawlerUtil"
 __email__ = "a154125960@gmail.com"
 
-from PaperCrawlerUtil.common_util import basic_config
 basic_config()
