@@ -1,6 +1,6 @@
 from pyquery import PyQuery as pq
-from proxypool.schemas import Proxy
-from proxypool.crawlers.base import BaseCrawler
+from PaperCrawlerUtil.proxypool.schemas import Proxy
+from PaperCrawlerUtil.proxypool.crawlers.base import BaseCrawler
 
 BASE_URL = 'http://www.data5u.com'
 
